/*
 * Amanda, The Advanced Maryland Automatic Network Disk Archiver
 * Copyright (c) 1991 University of Maryland
 * All Rights Reserved.
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of U.M. not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  U.M. makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * U.M. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.M.
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Author: James da Silva, Systems Design and Analysis Group
 *			   Computer Science Department
 *			   University of Maryland at College Park
 */
#include "amanda.h"

#include "clock.h"

times_t times_zero = {{0,0}};

static struct timeval timesub(end,start)
struct timeval end,start;
{
    struct timeval diff;

    if(end.tv_usec < start.tv_usec) { /* borrow 1 sec */
	end.tv_sec -= 1;
	end.tv_usec += 1000000;
    }
    diff.tv_usec = end.tv_usec - start.tv_usec;
    diff.tv_sec = end.tv_sec - start.tv_sec;
    return diff;
}

static struct timeval timeadd(a,b)
struct timeval a,b;
{
    struct timeval sum;

    sum.tv_sec = a.tv_sec + b.tv_sec;
    sum.tv_usec = a.tv_usec + b.tv_usec;

    if(sum.tv_usec >= 1000000) {
	sum.tv_usec -= 1000000;
	sum.tv_sec += 1;
    }
    return sum;
}

char *timestr(t)
struct timeval t;
{
    static char buf[40];

    sprintf(buf,"%d.%03d",t.tv_sec,t.tv_usec/1000);
    return buf;
}


static times_t start_time;
static int clock_running = 0;

void startclock()
{
    struct timezone dontcare;
    struct rusage ru;

    clock_running = 1;
    gettimeofday(&start_time.r,&dontcare);

#ifdef INSTRUMENTATION
    getrusage(RUSAGE_SELF,&ru);
    start_time.u = ru.ru_utime;
    start_time.s = ru.ru_stime;
#endif
}

times_t stopclock()
{
    times_t diff;
    struct timeval end_time;
    struct timezone dontcare;
    struct rusage ru;

    if(!clock_running) {
	fprintf(stderr,"stopclock botch\n");
	exit(1);
    }
    gettimeofday(&end_time, &dontcare);
    diff.r = timesub(end_time,start_time.r);
    clock_running = 0;

#ifdef INSTRUMENTATION
    getrusage(RUSAGE_SELF, &ru);
    diff.u = timesub(ru.ru_utime,start_time.u);
    diff.s = timesub(ru.ru_stime,start_time.s);
#endif

    return diff;
}

times_t curclock()
{
    times_t diff;
    struct timeval end_time;
    struct timezone dontcare;
    struct rusage ru;

    if(!clock_running) {
	fprintf(stderr,"curclock botch\n");
	exit(1);
    }
    gettimeofday(&end_time, &dontcare);
    diff.r = timesub(end_time,start_time.r);

#ifdef INSTRUMENTATION
    getrusage(RUSAGE_SELF, &ru);
    diff.u = timesub(ru.ru_utime,start_time.u);
    diff.s = timesub(ru.ru_stime,start_time.s);
#endif

    return diff;
}

times_t timesadd(a,b)
times_t a,b;
{
    times_t sum;

    sum.r = timeadd(a.r,b.r);

#ifdef INSTRUMENTATION
    sum.u = timeadd(a.u,b.u);
    sum.s = timeadd(a.s,b.s);
#endif

    return sum;
}

times_t timessub(a,b)
times_t a,b;
{
    times_t dif;

    dif.r = timesub(a.r,b.r);

#ifdef INSTRUMENTATION
    dif.u = timesub(a.u,b.u);
    dif.s = timesub(a.s,b.s);
#endif

    return dif;
}

char *times_str(t)
times_t t;
{
    static char str[256];

    sprintf(str, "rtime %d.%03d", t.r.tv_sec, t.r.tv_usec/1000);

#ifdef INSTRUMENTATION
    sprintf(str, "rtime %d.%03d utime %d.%03d stime %d.%03d",
	    t.r.tv_sec, t.r.tv_usec/1000,
	    t.u.tv_sec, t.u.tv_usec/1000,
	    t.s.tv_sec, t.s.tv_usec/1000);
#endif

    return str;
}

char *walltime_str(t)
times_t t;
{
    static char str[256];

    sprintf(str, "%d.%03d", t.r.tv_sec, t.r.tv_usec/1000);
    return str;
}
